@@ -14,7 +14,7 @@ from .ublox import core as ublox_core
 from .ublox import constants
 from .ublox import helpers
 from .ublox import receiver
-from .ublox import SERIAL_PORT_STR
+from .ublox import SERIAL_PORT_STR, BAUD_RATE_STR
 from . import OUTPUT_DIR_STR, NAME_STR, FILE_STR, JSON_STR, RATE_STR, MESSAGES_STR
 
 # ------------------------------------------------------------------------------
@@ -29,47 +29,47 @@ def config(**kwargs):
     conn_config = receiver.detect_connection(serial_port=serial_port)
 
     serial_port = conn_config[SERIAL_PORT_STR]
+    baudrate = conn_config[BAUD_RATE_STR]
 
-    logger.info(f'Attempting to configure device in serial port [ {serial_port} ]')
+    logger.info(f'Attempting to configure device in serial port [ {serial_port},{baudrate} ]')
 
-    stream = serial.Serial(serial_port)
+    with serial.Serial(serial_port, baudrate) as stream:
+        
+        config_file = kwargs.get(FILE_STR, None)
+        json_file = kwargs.get(JSON_STR, None)
+        if config_file:
+            logger.info(f'Configuring device from file [ {config_file} ]')
+            with open(config_file, 'r') as fh:
+                ublox_config.set_from_ucenter_file(stream, fh)
 
-    config_file = kwargs.get(FILE_STR, None)
-    json_file = kwargs.get(JSON_STR, None)
-    if config_file:
-        logger.info(f'Configuring device from file [ {config_file} ]')
-        with open(config_file, 'r') as fh:
-            ublox_config.set_from_ucenter_file(stream, fh)
+        elif json_file:
+            logger.info(f'Configuring device from JSON file [ {json_file} ]')
+            with open(json_file, 'r') as fh:
+                ublox_config.set_from_json_file(stream, fh) 
 
-    elif json_file:
-        logger.info(f'Configuring device from JSON file [ {json_file} ]')
-        with open(json_file, 'r') as fh:
-            ublox_config.set_from_json_file(stream, fh) 
+        else:
+            config_dict = {}
 
-    else:
-        config_dict = {}
+            if RATE_STR in kwargs:
+                config_dict[constants.RATE_STR] = {
+                    constants.MEASUREMENTS_STR : kwargs[RATE_STR],
+                    constants.SOLUTION_STR : kwargs[RATE_STR] * 5
+                }
 
-        if RATE_STR in kwargs:
-            config_dict[constants.RATES_STR] = {
-                constants.MEASUREMENTS_STR : kwargs[RATE_STR],
-                constants.SOLUTION_STR : kwargs[RATE_STR] * 5
-            }
+            logger.info(f'Configuring device from command line options: {config_dict}')
+            ublox_config.set_from_dict(stream, config_dict)
 
-        logger.info(f'Configuring device from command line options: {config_dict}')
-        ublox_config.set_from_dict(stream, config_dict)
-
-    stream.close()
 
 
 # ------------------------------------------------------------------------------
 
-def detect(serial_port=None, messages=False):
+def detect(serial_port=None, baudrate=None, messages=False):
 
-    config = receiver.detect_config(serial_port=serial_port, messages=messages)
+    config = receiver.detect_config(serial_port=serial_port, baudrate=baudrate, messages=messages)
 
     if not config:
         return False
-    
+
     json.dump(config, sys.stdout, indent=2, sort_keys=True)
     sys.stdout.write('\n')
     return True
@@ -95,13 +95,18 @@ def record(**kwargs):
 
     logger.debug('Record arguments ' + str(kwargs))
 
-    slice_period = rinex.FilePeriod.from_string(kwargs['slice'])
+    slice_period = kwargs.get('slice', rinex.FilePeriod.DAILY)
+    file_rotation = rinex.FilePeriod.from_string(slice_period)
+    recorder_config = {
+        'serial_port': kwargs.get(SERIAL_PORT_STR, None),
+        'baudrate': kwargs.get(BAUD_RATE_STR, None),
+        'file_rotation': file_rotation,
+        'output_dir': kwargs.get(OUTPUT_DIR_STR, '.'),
+        'receiver_name': kwargs.get(NAME_STR, 'UBLX')
+    }
 
     global _record_thread
-    _record_thread = receiver.Recorder(serial_port=kwargs.get(SERIAL_PORT_STR, None),
-                                   file_rotation=slice_period,
-                                   output_dir=kwargs[OUTPUT_DIR_STR],
-                                   receiver_name=kwargs[NAME_STR])
+    _record_thread = receiver.Recorder(**recorder_config)
 
     _record_thread.start()
 
