@@ -14,7 +14,7 @@ from roktools.time import weektow_to_datetime
 from . import helpers
 from . import config as ublox_config
 from . import core
-from . import SERIAL_PORT_STR, BAUD_RATE_STR
+from . import SERIAL_PORT_STR, BAUD_RATE_STR, DEFAULT_BAUD_RATE
 
 def autodetect_serial_port():
     """
@@ -39,17 +39,24 @@ def autodetect_baud_rate(serial_port):
     BAUD_RATE_LIST = [9600, 19200, 38400, 57600, 115200, 230400, 460800, 921600]
 
     baudrate = None
+    
     for baud_rate_candidate in BAUD_RATE_LIST:
         with serial.Serial(serial_port, baud_rate_candidate) as ser:
             if ser.isOpen(): ser.close()
             ser.open()
             doc = ser.read(1000)
             ser.close()
+            logger.debug(f'Testing baud rate: {baud_rate_candidate}')
 
-            if b'\xb5\x62' in doc:                        
+            if b'\xb5\x62' in doc:
                 baudrate = baud_rate_candidate
+                logger.debug(f'Baud rate detected: {baudrate}')
                 break
-        
+
+    if baudrate is None:
+        baudrate = DEFAULT_BAUD_RATE
+        logger.debug(f'Default baud rate selected: {baudrate}')
+
     return baudrate
 
 # ------------------------------------------------------------------------------
@@ -227,6 +234,7 @@ class Recorder(threading.Thread):
             os.makedirs(self.output_dir)
 
         self.serial_port = serial_port
+        self.baudrate = None
         if not self.serial_port:
             logger.info('Serial port not defined, autodetecting')
             connection_config = detect_connection()
@@ -261,13 +269,16 @@ class Recorder(threading.Thread):
 
     def run(self):
 
+        logger.debug('Starting recording thread')
+
         incoming_epoch_suffix = None
         for packet in core.ublox_packets(self.serial_stream, core.TIMEOUT_DEF):
 
             try:
                 packet_type, parsed_packet = core.parse(packet)
-            except KeyError:
-                packet_type = None
+            except Exception as e:
+                logger.debug("Could not parse packet: {}".format(e))
+                continue
             
             if packet_type == core.PacketType.RXM_RAWX:
                 tow = parsed_packet.rcvTow
@@ -275,6 +286,7 @@ class Recorder(threading.Thread):
                 epoch = weektow_to_datetime(tow, week)
 
                 incoming_epoch_suffix = self.slice.build_rinex3_epoch(epoch)
+                logger.debug("U-blox RXM_RAWX packet found! Epoch suffix {}".format(incoming_epoch_suffix))
 
             if not incoming_epoch_suffix:
                 continue
@@ -319,4 +331,4 @@ class Recorder(threading.Thread):
 
             logger.debug('Moving [ {} ] -> [ {} ]'.format(src, dst))
 
-            shutil.move(src, dst)
\ No newline at end of file
+            shutil.move(src, dst)
